@@ -4,8 +4,8 @@ with qw(Async::Microservice);
 sub service_name {return 'asmi-helloworld';}
 sub get_routes {return ('hello' => {defaults => {GET => 'GET_hello'}});}
 sub GET_hello {
-    my ($self, $this_req) = @_;
-    return $this_req->respond(200, [], 'Hello world!');
+    my ( $self, $this_req ) = @_;
+    return [ 200, [], 'Hello world!' ];
 }
 1;
 
